JustfileFixture.assert_variable_referenced()
Assert that variable is structurally referenced in recipe body fragments.
Usage
JustfileFixture.assert_variable_referenced(
recipe,
variable,
)Assert that variable is structurally referenced in recipe body fragments.
Usage