JustfileFixture.dry_run()

Run just --dry-run for any recipe, including shebang and script recipes.

Usage

JustfileFixture.dry_run(
    recipe,
    *args,
    env=None,
)

just --dry-run does not run recipes of any kind — linewise, shebang, or script. See https://github.com/casey/just/issues/3177.