JustfileFixture.assert_parameter()
Assert that recipe declares parameter, optionally checking attributes.
Usage
JustfileFixture.assert_parameter(
recipe,
parameter,
**expected,
)When called without keyword arguments, checks that the parameter exists. Each keyword argument is checked against the parameter’s dump payload.
Parameters
recipe-
Recipe name or namepath.
parameter-
Name of the parameter to inspect. **expected: Attribute name/value pairs to verify (e.g.
short="i",long="interactive",kind="singular").
Raises
AssertionError-
If the parameter does not exist or any attribute does not match.